@@ -1,19 +1,21 @@
 # -*- coding:utf-8 -*-
-import re
 
 import click
 
 from src.config import global_config, config_manager
+from src.config.global_config import compile_ip, compile_host_mame
 from src.local import http_server, pc_info
+from src.net import net_manager
 from src.server import server_config
 
 
-def validate_ip_type(ctx, param, value):
-    compile_ip = re.compile('^((25[0-5]|2[0-4]\d|[01]?\d\d?)\.){3}(25[0-5]|2[0-4]\d|[01]?\d\d?)$')
-    err_msg = '{}不符合ip格式!请检查后输入'.format(value)
+def validate_ip_or_host_name_type(ctx, param, value):
+    err_msg = '{}不符合ip/域名格式!请检查后输入'.format(value)
     try:
         if compile_ip.match(value):
             return value
+        elif compile_host_mame.match(value):
+            return value
         else:
             raise click.BadParameter(err_msg)
     except ValueError:
@@ -58,7 +60,7 @@ def server_list():
 
 @server.command("add", help='添加服务器配置')
 @click.option('--name', '-n', prompt='请输入服务器名称')
-@click.option('--host', '-h', prompt='请输入服务器地址', callback=validate_ip_type)
+@click.option('--host', '-h', prompt='请输入服务器地址', callback=validate_ip_or_host_name_type)
 @click.option('--port', '-p', prompt='请输入服务器ssh端口,默认为22', default=22)
 @click.option('--username', '-u', prompt='请输入服务器用户名')
 @click.option('--password', '-pwd', prompt='请输入密码')
@@ -77,12 +79,6 @@ def server_edit():
     server_config.server_edit()
 
 
-@server.command('sync-config', help='同步配置')
-@click.option('--model', '-m')
-def server_sync_config():
-    click.echo("同步server配置")
-
-
 @server.command('connect', help='🔗连接服务器')
 @click.option('--name', '-n', type=str, prompt='请输入服务器名称', help='服务器名称')
 def server_connect(name):
@@ -104,7 +100,7 @@ def local_pc_info():
 @local.command('http', help='根据指定文件夹开启临时http服务器')
 @click.option('--d', '-d', type=click.Path(exists=True), default='.', nargs=1, help='指定静态文件目录,默认为.')
 @click.option('--port', '-p', default=80, type=int, nargs=1, help='指定服务端口,默认为80')
-@click.option('--host', '-h', default='0.0.0.0', callback=validate_ip_type, type=str, nargs=1,
+@click.option('--host', '-h', default='0.0.0.0', callback=validate_ip_or_host_name_type, type=str, nargs=1,
               help='指定服务监听地址,默认为0.0.0.0')
 def local_tmp_http(d, port, host):
     http_server.http_server(d, port, host)
@@ -158,14 +154,11 @@ def net():
     pass
 
 
-@net.command('trace')
-def net_trace():
-    click.echo("跟踪网络")
-
-
-@net.command('open-socket')
-def net_open_socket():
-    click.echo("打开指定端口socket")
+@net.command('test', help='测试服务器是否可以打开socket')
+@click.option('--host', '-h', type=str, prompt='请输入服务器地址', callback=validate_ip_or_host_name_type, help='服务器地址')
+@click.option('--port', '-p', type=int, default=80, help='探测端口号(默认为80)')
+def net_test(host, port):
+    net_manager.net_test(host, port)
 
 
 # ming 函数
